function [S,C] = fakedata(a, nSamples)

%FAKEDATA       Create random samples according to a dicotomy given by
%               the hyperplane with normal vector a
%
%   X = FAKEDATA(W, NSAMPLES, M) creates NSAMPLES samples that can be linearly
%   separated by the hyperplane a'*x = 0 where x denotes a drawn sample.
%
%   Created: 2004 12 10 - Simon Meier

    
    % the samples are gaussian(Id, 0) distributed in the null space of a
    % => generate them

    m = 0.5;

    if (size(a,1) == 1)
        a = a';
    end;
    
    d = size(a,1);
    a_tilde = a(2:d);
    X = gsample(zeros(d-2,1), eye(d-2), nSamples);
    Y = 0.5*(gsample(0, 1, nSamples).^2 + gsample(0, 1, nSamples).^2);
    
    % and transform it into the null space of W'
    
    X = X*null(a(2:d)')';
    
    % and last but not least annotate and normalize them
    C = 2*round(rand(nSamples,1))-1;
    X = (X+(C.*(m+Y)-a(1))*a_tilde'/(a_tilde'*a_tilde));
    S = [ones(nSamples,1) X];
    
end
